package BPpackage;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.view.Menu;
import android.view.View;
import android.webkit.WebView;
import android.widget.Toast;
import java.util.Arrays;
import java.util.List;
import BPpackage.flashcards.*;


public class Flashcard extends Activity {
	public String headers = "Simplified\t\tTraditional\t\tPinyin\t\tDefinition";
	public String sizes = "64\t\t64\t\t32\t\t24";
	public String sides; // a = answer, q = front, x = unused
	public String[] cards; // lines from asset data files
	public String deck;
	public String set = "";
	public String record = "";

	public static final int SELECT_LESSON = 1;
	public static final int SELECT_SIDES = 2;
	public static final int STUDY = 3;
	public static final int TEST = 4;

	public static final int MENU_STUDY = Menu.FIRST;
	public static final int MENU_TEST = Menu.FIRST + 1;
	public static final int MENU_EXIT = Menu.FIRST + 2;

	public int MODE;
	public static final int PENDING_MODE = -1;
	public static final int STUDY_MODE = 0;
	public static final int TEST_MODE = 1;

	public PRAFileHandler fhandler = new PRAFileHandler(this);
	private WebView webview;

	private void findViews() {
		webview = (WebView) findViewById(R.id.webView1);
	}

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		String appname = getResources().getString(R.string.app_name);
		deck = appname.replace("Ruzhe ", "");
		// set view and pending mode
		setContentView(R.layout.activity_flashcard);
		findViews();
		webview.setScrollBarStyle(View.SCROLLBARS_INSIDE_OVERLAY);
		webview.getSettings().setBuiltInZoomControls(true);
		webview.getSettings().setSupportZoom(true);
		webview.loadUrl("file:///android_asset/flashcards.html");
		MODE = PENDING_MODE;

		// show eula on first use
		new SimpleEula(this).show();
	}

	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent intent) {
		super.onActivityResult(requestCode, resultCode, intent);
		if (intent != null) {

			if (resultCode == RESULT_OK) {
				switch (requestCode) {
				case SELECT_LESSON:
					cards = intent.getStringArrayExtra("SELECTION");
					set = intent.getStringExtra("SET"); 
					Intent j = new Intent(this, SideSelection.class);
					j.putExtra("HEADERS", headers);
					j.putExtra("MODE", MODE);
					startActivityForResult(j, SELECT_SIDES);
					break;
				case SELECT_SIDES:
					sides = intent.getStringExtra("SIDES");
					if (MODE == STUDY_MODE) {
						Intent k = new Intent(this, Study.class);
						k.putExtra("DECK", deck); 
						if (set == null){ set = ""; }
						k.putExtra("SET", set); 
						k.putExtra("SIDES", sides);
						k.putExtra("CARDS", cards);
						k.putExtra("HEADERS", headers);
						k.putExtra("SIZES", sizes);
						startActivityForResult(k, STUDY);
					} else {
						Intent l = new Intent(this, Test.class);
						l.putExtra("CARDS", cards);
						l.putExtra("SET", set); 
						l.putExtra("DECK", deck); 
						l.putExtra("SIDES", sides);
						l.putExtra("HEADERS", headers);
						l.putExtra("SIZES", sizes);
						startActivityForResult(l, TEST);
					}
					break;
				case STUDY:
					sides = intent.getStringExtra("SIDES");
					record = intent.getStringExtra("RECORD");
					// Toast.makeText(this, "Back with sides: "+sides,
					// Toast.LENGTH_SHORT).show();
					if (MODE == STUDY_MODE) {
						Intent m = new Intent(this, SideSelection.class);
						m.putExtra("HEADERS", headers);
						m.putExtra("MODE", MODE);
						startActivityForResult(m, SELECT_SIDES);
					}
					break;
				default:
					MODE = PENDING_MODE;
				}
			} else { // RESULT_CANCELED
				if ((MODE == STUDY_MODE) && (requestCode == SELECT_SIDES)) {
					List<String> top = Arrays.asList(record); 
					fhandler.writeToTopOfFile(top, "Memo.txt");
				}
				MODE = PENDING_MODE;
			}
		}
	}

	/**
	 * DeckSelection => CardSelection => SideSelection => Study
	 */
	public void modeStudy(View view) {
		MODE = STUDY_MODE;
		// get category section and card sides
		Intent i = new Intent(this, LessonSelection.class);
		startActivityForResult(i, SELECT_LESSON);
	}

	/**
	 * DeckSelection => SideSelection => Test
	 */
	public void modeTest(View view) {
		MODE = TEST_MODE;
		Intent i = new Intent(this, LessonSelection.class);
		i.putExtra("MODE", TEST_MODE);
		startActivityForResult(i, SELECT_LESSON);
	}

	public void memo(View view) {	
		Intent i = new Intent(this, Memo.class);
		startActivity(i);
	}

	private boolean doubleBackPressedOnce = false;

	@Override
	public void onBackPressed() {
		if (doubleBackPressedOnce) {
			super.onBackPressed();
			return;
		}
		doubleBackPressedOnce = true;
		Toast.makeText(this, R.string.exit_bkbtn, Toast.LENGTH_SHORT).show();
		new Handler().postDelayed(new Runnable() {

			@Override
			public void run() {
				doubleBackPressedOnce = false;
			}
		}, 2000);
	}


}
